Slot: range - LinkML Model

# Slot: range

defines the type of the object of the slot. Given the following slot definition S1: domain: C1 range: C2 the declaration X: S1: Y

implicitly asserts Y is an instance of C2

URI: linkml:range

## Domain and Range

SlotDefinition → 0..1 Element

## Parents

## Children

## Used by

- SlotDefinition

## Other properties

Comments: |  | range is underspecified, as not all elements can appear as the range of a slot.